#
# spec file for package sbc
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2012 B1 Systems GmbH, Vohburg, Germany.
# Copyright (c) 2025, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sonum 1
Name:           sbc
Version:        2.1
Release:        1.1
Summary:        Bluetooth Low-Complexity, Sub-Band Codec Utilities
License:        GPL-2.0-or-later
Group:          Hardware/Mobile
URL:            https://www.kernel.org/pub/linux/bluetooth
Source:         https://www.kernel.org/pub/linux/bluetooth/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(sndfile)

%description
The package contains utilities for using the SBC codec.

%package -n libsbc%{sonum}
Summary:        Bluetooth Low-Complexity, Sub-Band Codec Library
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n libsbc%{sonum}
The package contains libraries for using the SBC codec.

%package devel
Summary:        Development files for libsbc%{sonum}
License:        GPL-2.0-or-later
Group:          Development/Languages/C and C++
Requires:       libsbc%{sonum} = %{version}

%description devel
Development files for the SBC library.

%prep
%autosetup -p1

%build
%configure
%make_build

%install
%make_install
rm -v %{buildroot}/%{_libdir}/libsbc.la

%ldconfig_scriptlets -n libsbc%{sonum}

%files
%license COPYING
%doc ChangeLog README
%{_bindir}/sbcdec
%{_bindir}/sbcenc
%{_bindir}/sbcinfo

%files -n libsbc%{sonum}
%license COPYING.LIB
%{_libdir}/libsbc.so.%{sonum}*

%files devel
%dir %{_includedir}/sbc
%{_includedir}/sbc/sbc.h
%{_libdir}/libsbc.so
%{_libdir}/pkgconfig/sbc.pc

%changelog
* Thu Apr 17 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 2.1
  * Fix issue when compiling without SBC_BUILD_WITH_SSE_SUPPORT.
- Update to version 2.0
  * Fix issue with SSE primitives on non-x86.
- Drop patch:
  * fix-build-on-non-x86.patch (not longer needed)
- Use ldconfig_scriptlets macro
- Use correct Group tags
- Specfile cleanup
* Thu May 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Re-download fix-build-on-non-x86.patch: minor changes in the
  git signature.
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Sun Jan 17 2021 Dirk Müller <dmueller@suse.com>
- add fix-build-on-non-x86.patch: fix build on non-x86
* Mon Jan 11 2021 Dirk Müller <dmueller@suse.com>
- update to 1.5:
  * Add support for SSE primitives.
* Fri Aug  2 2019 Martin Liška <mliska@suse.cz>
- Use FAT LTO objects in order to provide proper static library.
* Thu Nov 15 2018 Stefan Seyfried <seife+obs@b1-systems.com>
- update to version 1.4:
  * Fix issue with stack overflow within sbc_crc8 function.
* Fri Nov  7 2014 hrvoje.senjan@gmail.com
- Provide baselibs.conf
- Update to version 1.3:
  * Fix issue with frame length calculation for dual-channel mode.
- Changes since 1.2:
  * Add support for setup from A2DP configuration data.
  * Add support for enabling high precision build.
- Changes since 1.1:
  * Add support for mSBC encoding and decoding functionality.
* Fri Aug 24 2012 seife+obs@b1-systems.com
- initial package, version 1.0
